import dataclasses

from typing import Optional

from polyswarmdconfig.config import Config


@dataclasses.dataclass
class Auth(Config):
    uri: Optional[str] = None

    @property
    def require_api_key(self):
        return self.uri is not None



import dataclasses

from typing import Optional

from polyswarmdconfig import Config


@dataclasses.dataclass
class Profiler(Config):
    enabled: bool = False
    db_uri: Optional[str] = None

    def __post_init__(self):
        if self.enabled and self.db_uri is None:
            raise ValueError('Profiler enabled, but no db uri set')



import dataclasses

from pykafka import KafkaClient
from typing import Optional

from polyswarmdconfig.config import Config


@dataclasses.dataclass
class Kafka(Config):
    brokers: str = ''
    broker_version: str = '1.1.1'
    use_greenlets: bool = True
    client: Optional[KafkaClient] = dataclasses.field(init=False, default=None)

    def __post_init__(self):
        if self.brokers:
            self.client = KafkaClient(hosts=self.brokers,
                                      use_greenlets=self.use_greenlets,
                                      broker_version=self.broker_version)
